https://shimo.im/docs/1nwJjnFqLT4gG6ax

【Task1(2天)】PyTorch的基本概念
# 

1. 什么是Pytorch，为什么选择Pytroch？

1. Pytroch的安装

1. 配置Python环境

1. 准备Python管理器

1. 通过命令行安装PyTorch

1. PyTorch基础概念 

---
### Install
```python
# Python 3.7
pip install https://download.pytorch.org/whl/cu100/torch-1.0.1.post2-cp37-cp37m-linux_x86_64.whl
pip install torchvision
```

### Example
[LR](https://github.com/Jie-Yuan/AI-Torch/blob/master/models/lr.py)

